@@ -28,7 +28,6 @@
 
 #include <kscreen/output.h>
 
-class CollapsableButton;
 class QCheckBox;
 class ResolutionSlider;
 class QLabel;
@@ -41,7 +40,7 @@ class OutputConfig : public QWidget
   public:
     explicit OutputConfig(QWidget *parent);
     explicit OutputConfig(const KScreen::OutputPtr &output, QWidget *parent = nullptr);
-    virtual ~OutputConfig();
+    ~OutputConfig() override;
 
     virtual void setOutput(const KScreen::OutputPtr &output);
     KScreen::OutputPtr output() const;
